; compute integrated brightness for apertures of varying size,
; using smoothed STinyTim model PSFs. Comparison w/ observed
; PSF indicates that something between x9 and x11 smoothing
; is about right.  Do it for 3 temperatures (10, 80, 1000K)
; 1000K is about as hot as you can go before the ghost would
; start to appear.

; apertures, in mips_enhancer native pixels.
me_pixsiz=2.49  ; enhancer native pixel size - see me_pixelsize.dat in DAT distrib.
aper =    [ 1.0, 1.5, 2.0, 2.5, 3.0, 4.0, 5.0, 6.0 ]; , 6.0, 8.0, 10.0]
naper = n_elements(aper)
sky1 = (aper + 1.) > 4
sky2 = 2*sky1

files = findfile('../images/psf24*sm9.fits',count=nf)

for ifile=0,nf-1 do begin

file = files[ifile]
ofile = strmid(file,0,strpos(file,'.fits')) + 'ApCorr.dat'

im = readfits(file,head)

scale = sxpar(head,'PIXSCALE')

; convert aperture and sky sizes from enhancer pixels to model image pixels
aper = aper * me_pixsiz / scale
sky1 = sky1 * me_pixsiz / scale
sky2 = sky2 * me_pixsiz / scale

; object position
;x0 = 940./2.
;y0 = 940./2.
xs = (size(im))[1]
x0 = xs / 2.
y0 = x0

;totcnts = total(im)
totcnts = 1.0

sz = size(im)
nx = sz[1]
ny = sz[2]

dn = fltarr(naper)
dnno = fltarr(naper)

centrod, im, x0, y0, 3.*me_pixsiz/scale, 0, 0, 0, xdum, ydum, counts
centrod, im, xdum, ydum, 3.*me_pixsiz/scale, 0, 0, 0, xcen, ycen, counts

; Photometry w/ NO sky annulus
aper,im,xcen,ycen,mag, err, skydn,skerr, 1., aper, [0,0],[0,0],/silent,/exact,/flux,setsky=0.
dnno = mag ; value for no sky subtraction

; Photometry w/ sky annuli
for i = 0,naper-1 do begin
  aper,im,xcen,ycen,mag, err, skydn,skerr, 1., aper[i], [sky1[i],sky2[i]],[0,0],/silent,/exact,/flux
  dn[i] = mag   ; 
endfor

apcor = totcnts/dn
apcorno = totcnts/dnno

aper = aper * scale / me_pixsiz
sky1 = sky1 * scale / me_pixsiz
sky2 = sky2 * scale / me_pixsiz

print,''
print,''
print,'Aperture Corrections derived from: ',file
print,'Aperture sizes in mips_enhancer native pixels of size',me_pixsiz,'"'
print,''
print,'Aperture corrections w/o Sky Annulus:'
print,'   Aper=',aper,form='(a,10(f8.1,1x))'
print,'        -------------------------------------------------------'
print, 'NoSky:  ', apcorno, form='(a,10(f8.3,1x))'
print,''
print,'Aperture corrections w/ Sky Annulus:'
print,'   Sky1=',sky1,form='(a,10(f8.1,1x))'
print,'   Sky2=',sky2,form='(a,10(f8.1,1x))'
print,'        -------------------------------------------------------'

openw,3,ofile
printf,3,'Aperture Corrections derived from: ',file
printf,3,'Aperture sizes in mips_enhancer native pixels of size',me_pixsiz,'"'
printf,3,''
printf,3,'Aperture corrections w/o Sky Annulus:'
printf,3,'   Aper=',aper,form='(a,10(f8.1,1x))'
printf,3,'        -------------------------------------------------------'
printf,3,'NoSky:  ', apcorno, form='(a,10(f8.3,1x))'
printf,3,''
printf,3,'Aperture corrections w/ Sky Annulus:'
printf,3,'   Sky1=',sky1,form='(a,10(f8.1,1x))'
printf,3,'   Sky2=',sky2,form='(a,10(f8.1,1x))'
printf,3,'        -------------------------------------------------------'

printf,3,'W/Sky:  ', apcor, form='(a,10(f8.3,1x))'
print, 'W/Sky:  ', apcor, form='(a,10(f8.3,1x))'

close,3

endfor

end

